@@ -27,7 +27,6 @@
 SharingPluginInterfaceSendResult vkontakte_send (SharingTransfer* transfer,
     ConIcConnection* con, gboolean* dead_mans_switch)
 {
-    SharingPluginInterfaceSendResult ret_val = SHARING_SEND_SUCCESS;
     SharingEntry *entry = sharing_transfer_get_entry(transfer);
     SharingAccount* account = sharing_entry_get_account(entry);
     SharingEntryMedia* media = NULL;
@@ -49,7 +48,7 @@ SharingPluginInterfaceSendResult vkontakte_send (SharingTransfer* transfer,
 
     gchar* account_name = sharing_account_get_param (account, "username");
 
-    if(!libvk_init((gchar*) proxy_host, proxy_port,account_name)){
+    if(!libvk_init((gchar*) proxy_host, proxy_port, account_name)){
         return SHARING_SEND_ERROR_UNKNOWN;
     }
 
@@ -71,13 +70,20 @@ SharingPluginInterfaceSendResult vkontakte_send (SharingTransfer* transfer,
         /* send photo */
         path_to_photo = sharing_entry_media_get_localpath(media);
         file_name = sharing_entry_media_get_filename(media);
-        libvk_uploadPhoto((gchar*)album, (gchar*)path_to_photo, file_name);
+        if (FALSE == libvk_uploadPhoto((gchar*)album, (gchar*)path_to_photo, file_name)) {
+            msa_print("%s:%d:%s: error upload photo\n", __FILE__, __LINE__, __FUNCTION__);
+            g_free(file_name);
+            libvk_uninit();
+            return SHARING_SEND_ERROR_UNKNOWN;
+        }
         g_free(file_name);
     }
 
-    dlclose(handle);
-    
-    return ret_val;
+    msa_print("%s:%d:%s: finish upload photo\n", __FILE__, __LINE__, __FUNCTION__);
+    libvk_get_settings (account);
+    libvk_uninit ();
+
+    return SHARING_SEND_SUCCESS;
 }
 
 
